@@ -1,5 +1,7 @@
 package Dist::Zilla::Plugin::ModuleBuildTiny;
-$Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.016';
+$Dist::Zilla::Plugin::ModuleBuildTiny::VERSION = '0.018';
+use 5.020;
+
 use Moose;
 with qw/
 	Dist::Zilla::Role::BuildPL
@@ -9,11 +11,13 @@ with qw/
 	Dist::Zilla::Role::MetaProvider
 /;
 
+use experimental qw/signatures postderef/;
+
 use Dist::Zilla 4.300039;
 use Module::Metadata;
 use Moose::Util::TypeConstraints 'enum';
 use MooseX::Types::Perl qw/StrictVersionStr/;
-use MooseX::Types::Moose qw(Str ArrayRef HashRef);
+use MooseX::Types::Moose qw/Bool Str ArrayRef/;
 use List::Util 1.33 qw/first any/;
 
 sub mvp_multivalue_args { qw(header_strs footer_strs) }
@@ -25,16 +29,13 @@ sub mvp_aliases {
     }
 }
 
-around BUILDARGS => sub {
-    my $orig = shift;
-    my $class = shift;
-
-    my $args = $class->$orig(@_);
+around BUILDARGS => sub($orig, $class, @args) {
+    my $args = $class->$orig(@args);
 
     my $delimiter = delete $args->{delimiter};
     if (defined $delimiter and length($delimiter)) {
         foreach my $arg (grep exists $args->{$_}, qw(header_strs footer_strs)) {
-            s/^\Q$delimiter\E// foreach @{$args->{$arg}};
+            s/^\Q$delimiter\E// foreach $args->{$arg}->@*;
         }
     }
 
@@ -49,21 +50,19 @@ has version_method => (
 
 has has_pl => (
 	is      => 'ro',
-	isa     => 'Bool',
+	isa     => Bool,
 	lazy    => 1,
-	default => sub {
-		my $self = shift;
-		return any { $_->name =~ /^lib\/.*\.PL$/ } @{ $self->zilla->files };
+	default => sub($self) {
+		return any { $_->name =~ /^lib\/.*\.PL$/ } $self->zilla->files->@*;
 	},
 );
 
 has has_xs => (
 	is      => 'ro',
-	isa     => 'Bool',
+	isa     => Bool,
 	lazy    => 1,
-	default => sub {
-		my $self = shift;
-		return any { $_->name =~ /^lib\/.*\.xs$/ } @{ $self->zilla->files };
+	default => sub($self) {
+		return any { $_->name =~ /^lib\/.*\.xs$/ } $self->zilla->files->@*;
 	},
 );
 
@@ -77,12 +76,11 @@ has version => (
 	is      => 'ro',
 	lazy    => 1,
 	isa     => StrictVersionStr,
-	default => sub {
-		my $self = shift;
+	default => sub($self) {
 		if ($self->version_method eq 'installed') {
 			return Module::Metadata->new_from_module('Module::Build::Tiny')->version->stringify;
 		}
-		elsif (-e 'include/' or any { $_->name =~ /^src\/.*\.c$/} @{ $self->zilla->files }) {
+		elsif (-e 'include/' or any { $_->name =~ /^src\/.*\.c$/} $self->zilla->files->@*) {
 			return '0.044';
 		}
 		elsif ($self->has_pl) {
@@ -99,8 +97,7 @@ has minimum_perl => (
 	is      => 'ro',
 	isa     => StrictVersionStr,
 	lazy    => 1,
-	default => sub {
-		my $self = shift;
+	default => sub($self) {
 		my $prereqs = $self->zilla->prereqs->cpan_meta_prereqs;
 		my $reqs = $prereqs->merged_requirements([ qw/configure build test runtime/ ], ['requires']);
 		return $reqs->requirements_for_module('perl') || '5.006';
@@ -108,7 +105,8 @@ has minimum_perl => (
 );
 
 has header_strs => (
-	is => 'ro', isa => ArrayRef[Str],
+	is => 'ro',
+	isa => ArrayRef[Str],
 	traits => ['Array'],
 	lazy => 1,
 	default => sub { [] },
@@ -128,10 +126,9 @@ has header => (
 	documentation => "A string included at the beginning of Makefile.PL",
 );
 
-sub _build_header {
-	my $self = shift;
+sub _build_header($self) {
 	join "\n",
-		@{$self->header_strs},
+		$self->header_strs->@*,
 		( $self->header_file
 			? do {
 				my $abs_file = path($self->zilla->root, $self->header_file);
@@ -143,7 +140,8 @@ sub _build_header {
 }
 
 has footer_strs => (
-	is => 'ro', isa => ArrayRef[Str],
+	is => 'ro',
+	isa => ArrayRef[Str],
 	traits => ['Array'],
 	lazy => 1,
 	default => sub { [] },
@@ -163,10 +161,9 @@ has footer => (
 	documentation => "A string included at the end of Makefile.PL",
 );
 
-sub _build_footer {
-	my $self = shift;
+sub _build_footer($self) {
 	join "\n",
-		@{$self->footer_strs},
+		$self->footer_strs->@*,
 		( $self->footer_file
 			? do {
 				my $abs_file = path($self->zilla->root, $self->footer_file);
@@ -177,11 +174,17 @@ sub _build_footer {
 			: () );
 }
 
+has auto_configure_requires => (
+	is => 'ro',
+	isa => Bool,
+	default => 1,
+);
 
 my $template = <<'BUILD_PL';
 # This Build.PL for {{ $dist_name }} was generated by {{ $plugin_title }}.
 use strict;
 use warnings;
+
 {{ $header }}
 use {{ $minimum_perl }};
 use Module::Build::Tiny{{ $version ne 0 && " $version" }};
@@ -189,34 +192,29 @@ Build_PL();
 {{ $footer }}
 BUILD_PL
 
-sub register_prereqs {
-	my ($self) = @_;
-
-	$self->zilla->register_prereqs({ phase => 'configure' }, 'Module::Build::Tiny' => $self->version);
+sub register_prereqs($self) {
+	if ($self->auto_configure_requires) {
+		$self->zilla->register_prereqs({ phase => 'configure' }, 'Module::Build::Tiny' => $self->version);
+	}
 
 	return;
 }
 
-sub can_static {
-	my $self = shift;
+sub can_static($self) {
 	return !$self->has_pl && !$self->has_xs;
 }
 
-sub metadata {
-	my $self = shift;
+sub metadata($self) {
 	my $static = $self->static eq 'yes' || $self->static eq 'auto' && $self->can_static;
 	return $static ? { x_static_install => 1 } : ();
 }
 
-sub gather_files {
-	my ($self) = @_;
-
-	if (my $file = first { $_->name eq 'Build.PL' } @{$self->zilla->files})
+sub gather_files($self) {
+	if (my $file = first { $_->name eq 'Build.PL' } $self->zilla->files->@*)
 	{
 		# if it's another type, some other plugin added it, so it's better to
 		# error out and let the developer sort out what went wrong.
-		if ($file->isa('Dist::Zilla::File::OnDisk'))
-		{
+		if ($file->isa('Dist::Zilla::File::OnDisk')) {
 			$self->log('replacing existing Build.PL found in repository');
 			$self->zilla->prune_file($file);
 		}
@@ -232,12 +230,10 @@ sub gather_files {
 	return;
 }
 
-sub setup_installer {
-	my ($self, $arg) = @_;
-
+sub setup_installer($self) {
 	confess 'Module::Build::Tiny is currently incompatible with dynamic_config' if $self->zilla->distmeta->{dynamic_config};
 
-	for my $map (map { $_->share_dir_map } @{$self->zilla->plugins_with(-ShareDir)}) {
+	for my $map (map { $_->share_dir_map } $self->zilla->plugins_with(-ShareDir)->@*) {
 		$self->log_fatal('Unsupported use of a module sharedir') if exists $map->{module};
 		$self->log_fatal('Sharedir location must be share/') if defined $map->{dist} and $map->{dist} ne 'share';
 	}
@@ -282,7 +278,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny - Build a Build.PL that uses Module::Build:
 
 =head1 VERSION
 
-version 0.016
+version 0.018
 
 =head1 DESCRIPTION
 
